==> GEMAP-0.0.3-py3-none-any.whl: GEMAP/__init__.py <==
import pandas as pd
import numpy as np
import pickle
import os


def GEMAP(GF=None):
	root = os.getcwd()+'/'+'TAMAP'
	if not os.path.exists(root):
		os.mkdir(root)
	################ gene name and Ids
	# allGenes=pd.read_csv(root+"/allGenesWithIds.csv",sep=";")
	# # stream = pkg_resources.resource_stream(__name__, 'data/allGenesWithIds.csv')
	# # allGenes=pd.read_csv(stream, encoding='latin-1')
	with importlib.resources.path('GEMAP', 'data') as data_path:
		default_config_path = data_path / "allGenesWithIds.csv"
		allGenes = pd.read_csv(default_config_path)

	print('allGenes.shape ',allGenes.shape)
	ginfo=pd.DataFrame()
	ginfo['id']=allGenes['ensembl_gene_id']
	ginfo['symbol']=allGenes['hgnc_symbol']
	print('ginfo.shape',ginfo.shape)
	geneIds={}
	idGenes={}
	for ii in range(ginfo.shape[0]):
    		idGenes[ginfo.loc[ii,'id']]=ginfo.loc[ii,'symbol']
    		geneIds[ginfo.loc[ii,'symbol']]=ginfo.loc[ii,'id']
	print('geneIds length ',len(geneIds))
	print('idGenes length ',len(idGenes))
	ids=np.unique(list(idGenes.values()))

	############### Input file
	genes=pd.read_excel(root+'/'+GF)
	genes=genes.T
	genes.columns=genes.loc['Unnamed: 0',]
	genes=genes.drop('Unnamed: 0',axis=0)
	genes.index=genes.loc[:,'Genes']
	genes=genes.drop('Genes',axis=1)
	print('genes.shape ',genes.shape)
	
	################# common genes and selected genes
	commonGenes=list(set(genes.columns).intersection(geneIds))
	genes=genes.loc[:,commonGenes]
	genes.columns=[geneIds[i] for i in genes.columns]

	# HVG=pd.read_csv(root+"/df_3_SS_he_uniform_relu_mae_adam_64_1024_1_fs.csv")
	# # stream = pkg_resources.resource_stream(__name__, 'data/df_3_SS_he_uniform_relu_mae_adam_64_1024_1_fs.csv')
	# # HVG=pd.read_csv(stream, encoding='latin-1')
	with importlib.resources.path('GEMAP', 'data') as data_path:
		default_config_path = data_path / "df_3_SS_he_uniform_relu_mae_adam_64_1024_1_fs.csv"
		HVG = pd.read_csv(default_config_path)
	
	genes=genes.loc[:,list(HVG['fs'])]
	print('genes.shape ',genes.shape)

	################# DL models
	with importlib.resources.path('GEMAP', 'data') as data_path:
		default_config_path = data_path / "df_3_SS_he_uniform_relu_mae_adam.pkl"
		file = open(default_config_path,'rb')
		dd2=pickle.load(file)
		file.close()

	norm=dd2["1_64_1024_norm"]
	model=dd2["1_64_1024_model"]
	cellLines=genes.index
	genes=norm.transform(genes)
	metabolites=model.predict(genes)
	metabolites=pd.DataFrame(metabolites)
	metabolites.columns=metabolites.columns+1
	metabolites.index=cellLines
	print(metabolites.head)
	metabolites.to_csv(root+"/metabolites.csv")
	
	################# returning data
	return metabolites

==> GEMAP-0.0.8-py3-none-any.whl: GEMAP/__init__.py <==
import pandas as pd
import numpy as np
import pickle
import os
import pkg_resources


def GEMAP(GF=None):
	root = os.getcwd()+'/'+'GEMAP'
	if not os.path.exists(root):
		os.mkdir(root)
	################ gene name and Ids
	data_path = pkg_resources.resource_filename('GEMAP', 'data/allGenesWithIds.csv')
	allGenes=pd.read_csv(data_path,sep=";")

	print('allGenes.shape ',allGenes.shape)
	ginfo=pd.DataFrame()
	ginfo['id']=allGenes['ensembl_gene_id']
	ginfo['symbol']=allGenes['hgnc_symbol']
	print('ginfo.shape',ginfo.shape)
	geneIds={}
	idGenes={}
	for ii in range(ginfo.shape[0]):
    		idGenes[ginfo.loc[ii,'id']]=ginfo.loc[ii,'symbol']
    		geneIds[ginfo.loc[ii,'symbol']]=ginfo.loc[ii,'id']
	print('geneIds length ',len(geneIds))
	print('idGenes length ',len(idGenes))
	ids=np.unique(list(idGenes.values()))

	############### Input file
	genes=pd.read_excel(root+'/'+GF)
	genes=genes.T
	genes.columns=genes.loc['Unnamed: 0',]
	genes=genes.drop('Unnamed: 0',axis=0)
	genes.index=genes.loc[:,'Genes']
	genes=genes.drop('Genes',axis=1)
	print('genes.shape ',genes.shape)
	
	################# common genes and selected genes
	commonGenes=list(set(genes.columns).intersection(geneIds))
	genes=genes.loc[:,commonGenes]
	genes.columns=[geneIds[i] for i in genes.columns]

	data_path = pkg_resources.resource_filename('GEMAP', 'data/df_3_SS_he_uniform_relu_mae_adam_1_64_1024.pkl')
	file = open(data_path,'rb')
	dd5=pickle.load(file)
	file.close()

	HVG=dd5["fs"]
	genes=genes.loc[:,HVG]
	print('genes.shape ',genes.shape)

	################# DL models
	norm=dd5["norm"]
	model=dd5["model"]
	cellLines=genes.index
	genes=norm.transform(genes)
	metabolites=model.predict(genes)
	metabolites=pd.DataFrame(metabolites)
	metabolites.columns=metabolites.columns+1
	metabolites.index=cellLines
	print(metabolites.head)
	metabolites.to_csv(root+"/metabolites.csv")
	
	################# returning data
	return metabolites
